from setuptools import setup

setup(name='abdalla_dsnd_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['abdalla_dsnd_distributions'],
      zip_safe=False)
